<?php


if ( !defined( 'ABSPATH' ) ) exit;

/**
 * Register our styles
 *
 * @return void
 */

/**
 * Register thumbnail sizes.
 *
 * @return void
 */
function category_posts_add_image_size(){
	$sizes = get_option('clesarmedia_cat_post_thumb_sizes');
	
	if ( $sizes ){
		foreach ( $sizes as $id=>$size ) {
			add_image_size( 'cat_post_thumb_size' . $id, $size[0], $size[1], true );
		}
	}
}

add_action( 'init', 'category_posts_add_image_size' );


/**
 * Category Posts Widget Class
 *
 * Shows the single category posts with some configurable options
 */
class CategoryPosts extends WP_Widget {
    
  // Configuration globale du widget
  function __construct() {
    $widget_ops = array('classname' => 'cat-post-widget', 'description' => 'List single category posts. by EightPixelDesign');
    
      $control_args = array(
      
    );
 
    parent::__construct(
      'CategoryPosts',
      'Sidebar Category Posts',
      $widget_ops,
      $control_args
    );
  }
	// Displays category posts widget on blog.
	function widget($args, $instance) {
		global $post;
		$post_old = $post; // Save the post object.
		
		extract( $args );
		
		$sizes = get_option('clesarmedia_cat_post_thumb_sizes');
		
		// If not title, use the name of the category.
		if( !$instance["title"] ) {
			$category_info = get_category($instance["cat"]);
			$instance["title"] = $category_info->name;
	  }
		// Get array of post info.
	  $cat_posts = new WP_Query(
		"showposts=" . $instance["num"] . 
		"&cat=" . $instance["cat"] 
	  );


		
		echo $before_widget;
		
		// Widget title
		echo $before_title;

			echo '<a href="' . get_category_link($instance["cat"]) . '">' . $instance["title"] . '</a>';
		echo $after_title;

		// Post list
		if ( isset( $instance['sidebar'] ) ) :
			echo "<div class='catpostsitemcontainer'>\n";
			
			while ( $cat_posts->have_posts() )
			{
				$cat_posts->the_post();
			?>
				<div class="cat-post-item">
					<div class="image-cat-posts-sidebar">
						<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>">
							<?php if ( ! post_password_required() && ! is_attachment() ) :the_post_thumbnail(); endif; ?>
						</a>		
					</div>					
					<div class="content-cat-posts-sidebar">
						<a class="post-title" href="<?php the_permalink(); ?>" rel="bookmark" title="Permanent link to <?php the_title_attribute(); ?>"><?php the_title(); ?></a>
						<p>
	                		<i class="author"></i><?php the_author_link(); ?> &nbsp;
	                	</p>
					</div>
					<div class="clear"></div>
				</div>
				<?php
			}
			
			echo "</div>\n";
		endif;

		if ( isset( $instance['footer'] ) ) :
			echo "<div class='catpostsitemcontainerfooter'>\n";
			
			while ( $cat_posts->have_posts() )
			{
				$cat_posts->the_post();
			?>
				<div class="cat-post-item-footer">
					<div class="image-cat-posts-footer">
						<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>">
							<?php if ( ! post_password_required() && ! is_attachment() ) :the_post_thumbnail(); endif; ?>
						</a>		
					</div>					
					<div class="content-cat-posts-footer">
						<a class="post-title" href="<?php the_permalink(); ?>" rel="bookmark" title="Permanent link to <?php the_title_attribute(); ?>"><?php echo new_title('...', 7); ?></a>
						<p>
	                		<i class="author"></i><?php the_author_link(); ?> &nbsp;
	                	</p>
					</div>
					<div class="clear"></div>
				</div>
				<?php
			}
			
			echo "</div>\n";
		endif;
		
		echo $after_widget;
		
		wp_reset_postdata();
	
	}

	/**
	 * Update the options
	 *
	 * @param  array $new_instance
	 * @param  array $old_instance
	 * @return array
	 */
	function update($new_instance, $old_instance) {
		$sizes = get_option('clesarmedia_cat_post_thumb_sizes');
			
		if ( !$sizes ) {
			$sizes = array();
		}
		
		$sizes[$this->id] = array($new_instance['thumb_w'], $new_instance['thumb_h']);
		update_option('clesarmedia_cat_post_thumb_sizes', $sizes);
				
		return $new_instance;
	}

	/**
	 * The widget configuration form back end.
	 *
	 * @param  array $instance
	 * @return void
	 */
	function form($instance) {
		$instance = wp_parse_args( ( array ) $instance, array(
			'title'          => '',
			'cat'			 => '',
			'num'            => '',
			'sidebar'        => '',
			'footer'         => '',
		) );

		$title          = $instance['title'];
		$cat 			= $instance['cat'];
		$num            = $instance['num'];
		$sidebar        = $instance['sidebar'];
		$footer        = $instance['footer'];
			?>
			<p>
				<label for="<?php echo $this->get_field_id("sidebar"); ?>">
					<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id("sidebar"); ?>" name="<?php echo $this->get_field_name("sidebar"); ?>"<?php checked( (bool) $instance["sidebar"], true ); ?> />
					Sidebar style
				</label>
				<label for="<?php echo $this->get_field_id("footer"); ?>">
					<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id("footer"); ?>" name="<?php echo $this->get_field_name("footer"); ?>"<?php checked( (bool) $instance["footer"], true ); ?> />
					footer style
				</label>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id("title"); ?>">
					Title :
					<input class="widefat" id="<?php echo $this->get_field_id("title"); ?>" name="<?php echo $this->get_field_name("title"); ?>" type="text" value="<?php echo esc_attr($instance["title"]); ?>" />
				</label>
			</p>
			
			<p>
				<label>
					Category :
					<?php wp_dropdown_categories( array( 'name' => $this->get_field_name("cat"), 'selected' => $instance["cat"] ) ); ?>
				</label>
			</p>
			
			<p>
				<label for="<?php echo $this->get_field_id("num"); ?>">
					Number of posts to show :
					<input style="text-align: center;" id="<?php echo $this->get_field_id("num"); ?>" name="<?php echo $this->get_field_name("num"); ?>" type="text" value="<?php echo absint($instance["num"]); ?>" size='3' />
				</label>
			</p>
			<?php

		}

}

add_action( 'widgets_init', create_function('', 'return register_widget("CategoryPosts");') );
